==> jc-1.4.0.tar.gz: jas/LabelOperand.h <==
// class jas.LabelOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class dbcdfc5ef03f49dc jas_LabelOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_LabelOperand_H_
#define _JC_jas_LabelOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Insn$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LabelOperand$sub_refs	_jc_jas_LabelOperand$sub_refs;
typedef struct _jc_jas_LabelOperand$sub_nonrefs	_jc_jas_LabelOperand$sub_nonrefs;
typedef struct _jc_jas_LabelOperand$refs	_jc_jas_LabelOperand$refs;
typedef struct _jc_jas_LabelOperand$nonrefs	_jc_jas_LabelOperand$nonrefs;
typedef struct _jc_jas_LabelOperand$object	_jc_jas_LabelOperand$object;

typedef const struct _jc_jas_LabelOperand$vmethods	_jc_jas_LabelOperand$vmethods;
typedef const struct _jc_jas_LabelOperand$vtable	_jc_jas_LabelOperand$vtable;
typedef const struct _jc_jas_LabelOperand$vtype	_jc_jas_LabelOperand$vtype;

// Constructors
extern void _jc_jas_LabelOperand$method$_init$49e64e3e6c09a205(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_Label$object *, struct _jc_jas_Insn$object *);
extern void _jc_jas_LabelOperand$method$_init$269e81fcfdf76d1b(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_Label$object *, struct _jc_jas_Insn$object *, jboolean);

// Virtual methods
extern void _jc_jas_LabelOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_LabelOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_LabelOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_LabelOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LabelOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_LabelOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_LabelOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_LabelOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_LabelOperand$vmethods	jas_LabelOperand;
};

// Vtype
struct _jc_jas_LabelOperand$vtype {
	_jc_type			type;
	_jc_jas_LabelOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LabelOperand$sub_refs {
	struct _jc_jas_Label$object	*target;
	struct _jc_jas_Insn$object	*source;
};

// Reference instance fields (object)
struct _jc_jas_LabelOperand$refs {
    _jc_jas_LabelOperand$sub_refs	jas_LabelOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LabelOperand$sub_nonrefs {
	jboolean	wide;
};

// Non-reference instance fields (object)
struct _jc_jas_LabelOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_LabelOperand$sub_nonrefs	jas_LabelOperand;
};

// Object instance structure
struct _jc_jas_LabelOperand$object {
	_jc_jas_LabelOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LabelOperand$vtype	*vtype;
	_jc_jas_LabelOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LabelOperand$vtype _jc_jas_LabelOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LabelOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LabelOperand$class_object;

#endif	/* _JC_jas_LabelOperand_H_ */

==> jc-1.4.6.tar.gz: jas/LabelOperand.h <==
// class jas.LabelOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class dbcdfc5ef03f49dc jas_LabelOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_LabelOperand_H_
#define _JC_jas_LabelOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Insn$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LabelOperand$sub_refs	_jc_jas_LabelOperand$sub_refs;
typedef struct _jc_jas_LabelOperand$sub_nonrefs	_jc_jas_LabelOperand$sub_nonrefs;
typedef struct _jc_jas_LabelOperand$refs	_jc_jas_LabelOperand$refs;
typedef struct _jc_jas_LabelOperand$nonrefs	_jc_jas_LabelOperand$nonrefs;
typedef struct _jc_jas_LabelOperand$object	_jc_jas_LabelOperand$object;

typedef const struct _jc_jas_LabelOperand$vmethods	_jc_jas_LabelOperand$vmethods;
typedef const struct _jc_jas_LabelOperand$vtable	_jc_jas_LabelOperand$vtable;
typedef const struct _jc_jas_LabelOperand$vtype	_jc_jas_LabelOperand$vtype;

// Constructors
extern void _jc_jas_LabelOperand$method$_init$49e64e3e6c09a205(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_Label$object *, struct _jc_jas_Insn$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LabelOperand$method$_init$269e81fcfdf76d1b(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_Label$object *, struct _jc_jas_Insn$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_LabelOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_LabelOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LabelOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_LabelOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LabelOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_LabelOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_LabelOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LabelOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_LabelOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_LabelOperand$vmethods	jas_LabelOperand;
};

// Vtype
struct _jc_jas_LabelOperand$vtype {
	_jc_type			type;
	_jc_jas_LabelOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LabelOperand$sub_refs {
	struct _jc_jas_Label$object	*target;
	struct _jc_jas_Insn$object	*source;
};

// Reference instance fields (object)
struct _jc_jas_LabelOperand$refs {
    _jc_jas_LabelOperand$sub_refs	jas_LabelOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LabelOperand$sub_nonrefs {
	jboolean	wide;
};

// Non-reference instance fields (object)
struct _jc_jas_LabelOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_LabelOperand$sub_nonrefs	jas_LabelOperand;
};

// Object instance structure
struct _jc_jas_LabelOperand$object {
	_jc_jas_LabelOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LabelOperand$vtype	*vtype;
	_jc_jas_LabelOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LabelOperand$vtype _jc_jas_LabelOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LabelOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LabelOperand$class_object;

#endif	/* _JC_jas_LabelOperand_H_ */
